@@ -17,6 +17,7 @@ public final class Frui {
     private static final int STATUS_UNEXPECTED = -1;
 
     private static final String KEYWORD_SHOTAGE = "shotage";
+    private static final String RANGE_OP = "..";
 
     /**
      * Frui̐B
@@ -31,9 +32,7 @@ public final class Frui {
      * @param condition 
      * @param isNegative NOTw肳Ăꍇ <code>true</code>
      */
-    private static void addCondition(List operationList,
-                                     Condition condition,
-                                     boolean isNegative) {
+    private static void addCondition(List operationList, Condition condition, boolean isNegative) {
         condition.setNegative(isNegative);
         operationList.add(condition);
     }
@@ -53,20 +52,18 @@ public final class Frui {
      * @param expression [̕\
      */
     private static void setDepth(Application application, String expression) {
-        final String RANGE = "..";
-        int index = expression.indexOf(RANGE);
+        int index = expression.indexOf(RANGE_OP);
         try {
             if (index >= 0) {
                 if (index == 0) { // startsWith
-                    String to = expression.substring(RANGE.length());
+                    String to = expression.substring(RANGE_OP.length());
                     application.setMaxDepth(Integer.parseInt(to));
-                } else if (expression.endsWith(RANGE)) {
-                    String from = expression.substring(0, expression.length()
-                                                          - RANGE.length());
+                } else if (expression.endsWith(RANGE_OP)) {
+                    String from = expression.substring(0, expression.length() - RANGE_OP.length());
                     application.setMinDepth(Integer.parseInt(from));
                 } else {
                     String from = expression.substring(0, index);
-                    String to = expression.substring(index + RANGE.length());
+                    String to = expression.substring(index + RANGE_OP.length());
                     application.setMinDepth(Integer.parseInt(from));
                     application.setMaxDepth(Integer.parseInt(to));
                 }
@@ -86,9 +83,7 @@ public final class Frui {
      * @param message bZ[W
      */
     private static void throwException(String operationName, String message) {
-        throw new IllegalArgumentException(message
-                                           + Constants.MESSAGE_SEPARATOR
-                                           + operationName);
+        throw new IllegalArgumentException(message + Constants.MESSAGE_SEPARATOR + operationName);
     }
 
     /**
@@ -119,38 +114,83 @@ public final class Frui {
             Notice.printUsage();
             return STATUS_OK;
         }
+        String argument = args[0];
+        /*
+         * 
+         */
+        // version
+        if (argument.equals("-v") || argument.equals("--version")) {
+            Notice.printVersion(false);
+            return STATUS_OK;
+        }
+        if (argument.equals("-V") || argument.equals("--VERSION")) {
+            Notice.printVersion(true);
+            return STATUS_OK;
+        }
+        // help
+        if (argument.equals("-h") || argument.equals("--help")) {
+            Notice.printUsage();
+            return STATUS_OK;
+        }
         Application application = new Application();
+        Operation[] operations = parseOption(args, application);
+        if (application.isVerbose()) {
+            VerboseMode.invoke(application, operations);
+        } else {
+            application.invoke(operations);
+        }
+        return STATUS_OK;
+    }
+
+    /**
+     * IvV͂B
+     * @param optionString IvV
+     * @return Operation̔z
+     */
+    public static Operation[] parseOption(String optionString) {
+        return parseOption(optionString, new Application());
+    }
+
+    /**
+     * IvV͂B
+     * @param optionStrings IvV̔z
+     * @return Operation̔z
+     */
+    public static Operation[] parseOption(String[] optionStrings) {
+        return parseOption(optionStrings, new Application());
+    }
+
+    /**
+     * IvV͂B
+     * @param optionString IvV
+     * @param application AvP[V
+     * @return Operation̔z
+     */
+    public static Operation[] parseOption(String optionString, Application application) {
+        return parseOption(optionString.split(" "), application);
+    }
+
+    /**
+     * IvV͂B
+     * @param optionStrings IvV
+     * @param application AvP[V
+     * @return Operation̔z
+     */
+    public static Operation[] parseOption(String[] optionStrings, Application application) {
+        String[] args = optionStrings; // alias
         List operationList = new ArrayList();
         List operationListReference = operationList;
         boolean selectedReplace = false;
         boolean selectedZip = false;
         for (int i = 0, n = args.length; i < n; i++) {
             String argument = args[i];
-            /*
-             * 
-             */
-            // version
-            if (argument.equals("-v") || argument.equals("--version")) {
-                Notice.printVersion(false);
-                return STATUS_OK;
-            }
-            if (argument.equals("-V") || argument.equals("--VERSION")) {
-                Notice.printVersion(true);
-                return STATUS_OK;
-            }
-            // help
-            if (argument.equals("-h") || argument.equals("--help")) {
-                Notice.printUsage();
-                return STATUS_OK;
-            }
             /*
              * 
              */
             // directory
             if (argument.equals("-d") || argument.equals("--directory")) {
                 if (++i >= n) {
-                    throwException("directory",
-                                   getErrorMessage(KEYWORD_SHOTAGE));
+                    throwException("directory", getErrorMessage(KEYWORD_SHOTAGE));
                 }
                 File directory = new File(args[i]);
                 if (!directory.isDirectory()) {
@@ -287,9 +327,7 @@ public final class Frui {
                 if (++i >= n) {
                     throwException("size", getErrorMessage(KEYWORD_SHOTAGE));
                 }
-                addCondition(operationList,
-                             Size.getInstance(args[i]),
-                             isNegative);
+                addCondition(operationList, Size.getInstance(args[i]), isNegative);
                 continue;
             }
             // time
@@ -310,9 +348,7 @@ public final class Frui {
                 if (++i >= n) {
                     throwException("examine", getErrorMessage(KEYWORD_SHOTAGE));
                 }
-                addCondition(operationList,
-                             Examine.getInstance(args[i]),
-                             isNegative);
+                addCondition(operationList, Examine.getInstance(args[i]), isNegative);
                 continue;
             }
             // zip
@@ -357,6 +393,16 @@ public final class Frui {
                 operationList.add(new PrintQuiet());
                 continue;
             }
+            // suffix
+            if (argument.equals("--suffix")) {
+                operationList.add(new PrintSuffixSet());
+                continue;
+            }
+            // fullpath
+            if (argument.equals("--fullpath")) {
+                operationList.add(new PrintFullPath());
+                continue;
+            }
             /*
              * ړ
              */
@@ -412,6 +458,14 @@ public final class Frui {
                 continue;
             }
             // illegal option
+            if (argument.equals("-v")
+                || argument.equals("--version")
+                || argument.equals("-V")
+                || argument.equals("--VERSION")
+                || argument.equals("-h")
+                || argument.equals("--help")) {
+                throwException(argument, getErrorMessage("illegalposition"));
+            }
             throwException(argument, getErrorMessage("illegaloption"));
         }
         operationList = operationListReference;
@@ -425,12 +479,7 @@ public final class Frui {
         if (ignore.isEnabled()) {
             operationList.add(0, ignore);
         }
-        if (application.isVerbose()) {
-            VerboseMode.invoke(application, operationList);
-        } else {
-            application.invoke(operationList);
-        }
-        return STATUS_OK;
+        return (Operation[])operationListReference.toArray(new Operation[operationListReference.size()]);
     }
 
     /**
@@ -459,9 +508,7 @@ public final class Frui {
             default:
                 message = Messages.getString("error.type.unknown");
         }
-        System.err.println(message
-                           + Constants.MESSAGE_SEPARATOR
-                           + ex.getMessage());
+        System.err.println(message + Constants.MESSAGE_SEPARATOR + ex.getMessage());
         System.err.println(Messages.getString("error.see.manual"));
     }
 
